@@ -1,5 +1,6 @@
 import json
 import os
+from typing import Any, Dict
 
 from pyseto.utils import base64url_decode
 
@@ -14,7 +15,7 @@ def load_key(name: str) -> str:
     return k
 
 
-def load_jwk(name: str) -> str:
+def load_jwk(name: str) -> Dict[str, Any]:
     with open(get_path(name)) as key_file:
         jwk = json.loads(key_file.read())
     res = {}
